diff --git a/tests/psalm-baseline.xml b/tests/psalm-baseline.xml
index 7d91178c..4ee21a00 100644
--- a/tests/psalm-baseline.xml
+++ b/tests/psalm-baseline.xml
@@ -42,6 +42,8 @@
+
+
diff --git a/lib/Service/AssistantService.php b/lib/Service/AssistantService.php
index 7ec1fe03..a3bff54c 100644
--- a/lib/Service/AssistantService.php
+++ b/lib/Service/AssistantService.php
@@ -173,7 +173,17 @@ public function getAvailableTaskTypes(): array {
}
/** @var string $typeId */
foreach ($availableTaskTypes as $typeId => $taskTypeArray) {
- // skip chat task type (not directly useful to the end user)
+ // skip chat, chat with tools and ContextAgent task types (not directly useful to the end user)
+ if (!self::DEBUG) {
+ if (class_exists('OCP\\TaskProcessing\\TaskTypes\\TextToTextChatWithTools')
+ && $typeId === \OCP\TaskProcessing\TaskTypes\TextToTextChatWithTools::ID) {
+ continue;
+ }
+ if (class_exists('OCP\\TaskProcessing\\TaskTypes\\ContextAgentInteraction')
+ && $typeId === \OCP\TaskProcessing\TaskTypes\ContextAgentInteraction::ID) {
+ continue;
+ }
+ }
if ($typeId === TextToTextChat::ID) {
// add the chattyUI virtual task type
$types[] = [
@@ -191,7 +201,9 @@ public function getAvailableTaskTypes(): array {
'priority' => self::TASK_TYPE_PRIORITIES['chatty-llm'] ?? 1000,
];
// do not add the raw TextToTextChat type
- continue;
+ if (!self::DEBUG) {
+ continue;
+ }
}
$taskTypeArray['id'] = $typeId;
$taskTypeArray['priority'] = self::TASK_TYPE_PRIORITIES[$typeId] ?? 1000;